Rando ALgo is a CLI APP that allows users to practice random algorithm questions based on the number of questions they pick. 
To use this app users have to have login and enter in a password, after this they can now enter a number to practice algorithm questions.
User can play as many times as they want to but if they no longer wish to continue, they can exit and be shown all answers of the algorithm questions.
